Exception: AdWords::Error::UnknownType

Inherits:
Error
  • Object
show all
Defined in:
lib/adwords4r.rb

Overview

Raised if an attempt is made to instantiate a type that does not exist in the AdWords SOAP API