Libraries
»
adwords4r
(19.4.0)
»
Index (U)
»
AdWords
»
Error
»
UnknownType
Exception: AdWords::Error::UnknownType
Inherits:
Error
Object
StandardError
Error
AdWords::Error::UnknownType
show all
Defined in:
lib/adwords4r.rb
Overview
Raised if an attempt is made to instantiate a type that does not exist in the AdWords SOAP API